@@ -326,6 +326,10 @@
 #include "token_info-5.29.10.h"
 #elif PERL_VERSION == 30 && PERL_SUBVERSION == 0
 #include "token_info-5.30.0.h"
+#elif PERL_VERSION == 30 && PERL_SUBVERSION == 1
+#include "token_info-5.30.0.h"
+#elif PERL_VERSION == 30 && PERL_SUBVERSION == 2
+#include "token_info-5.30.0.h"
 #elif PERL_VERSION == 30
 #include "token_info-5.30.0.h"
 #elif PERL_VERSION == 31 && PERL_SUBVERSION == 0
@@ -336,7 +340,19 @@
 #include "token_info-5.31.2.h"
 #elif PERL_VERSION == 31 && PERL_SUBVERSION == 3
 #include "token_info-5.31.3.h"
-#elif PERL_VERSION > 31 || (PERL_VERSION == 31 && PERL_SUBVERSION > 3)
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 4
+#include "token_info-5.31.3.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 5
+#include "token_info-5.31.5.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 6
+#include "token_info-5.31.5.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 7
+#include "token_info-5.31.5.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 8
+#include "token_info-5.31.5.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 9
+#include "token_info-5.31.5.h"
+#elif PERL_VERSION > 31 || (PERL_VERSION == 31 && PERL_SUBVERSION > 9)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
